---
title: <span class="badge object-type-scalar"></span> DurationMilliseconds
---
# <span class="badge object-type-scalar"></span> DurationMilliseconds

Time: duration (ms)

## Definition

```python
# Time: duration (ms)
DurationMilliseconds: typing.Literal["dtdurationms"] = "dtdurationms"
```
